@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 VTool - Computer vision tools
 
@@ -6,9 +5,7 @@ Autogenerate Command:
     mkinit vtool_ibeis -i
 """
 # flake8: noqa
-from __future__ import absolute_import, division, print_function
-
-__version__ = '2.2.0'
+__version__ = '2.2.1'
 __author__ = 'Jon Crall, Avi Weinstock, Chuck Stewart, Hendrik Weideman, Jason Parham, Zackary Rutfield'
 __author_email__ = 'erotemic@gmail.com'
 __url__ = 'https://github.com/Erotemic/vtool_ibeis'
