@@ -1,6 +1,4 @@
-# -*- coding: utf-8 -*-
-from __future__ import absolute_import, division, print_function, unicode_literals
-from six.moves import zip, range, map, reduce  # NOQA
+from functools import reduce
 import cv2
 import numpy as np
 import utool as ut
