@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
 """
     vt
     python -m utool.util_inspect check_module_usage --pat="matching.py"
 
 """
-from __future__ import absolute_import, division, print_function
 from vtool_ibeis import _rhomb_dist
 import six
 import warnings
@@ -576,7 +574,7 @@ class PairwiseMatch(ub.NiceRepr):
             ori_err = np.full(n_fm, fill_value=np.inf)
             agg_errors = (xy_err, scale_err, ori_err)
 
-            agg_inlier_flags = np.zeros(n_fm, dtype=np.bool)
+            agg_inlier_flags = np.zeros(n_fm, dtype=bool)
 
             agg_H_12 = None
             prev_best = 50
@@ -1636,7 +1634,7 @@ def asymmetric_correspondence(annot1, annot2, K, Knorm, checks, allow_shrink=Tru
 
     fx2_to_fx1, fx2_to_dist = normalized_nearest_neighbors(
         annot1['flann'], annot2['vecs'], num_neighbors, checks)
-    fx2_to_flags = np.ones((len(fx2_to_fx1), K), dtype=np.bool)
+    fx2_to_flags = np.ones((len(fx2_to_fx1), K), dtype=bool)
     # Assign correspondences
     assigntup = assign_unconstrained_matches(fx2_to_fx1, fx2_to_dist, K,
                                              Knorm, fx2_to_flags)
@@ -1706,8 +1704,8 @@ def assign_symmetric_matches(fx2_to_fx1, fx2_to_dist, fx1_to_fx2, fx1_to_dist,
     fx12.columns.name = 'K'
     fx12.index.name = 'fx2'
 
-    fx12 = fx12.T[0:K].T.astype(np.float)
-    fx21 = fx21.T[0:K].T.astype(np.float)
+    fx12 = fx12.T[0:K].T.astype(float)
+    fx21 = fx21.T[0:K].T.astype(float)
 
     fx12.values[~fx1_to_flags] = np.nan
     fx21.values[~fx2_to_flags] = np.nan
@@ -1867,7 +1865,7 @@ def assign_unconstrained_matches(fx2_to_fx1, fx2_to_dist, K, Knorm=None,
         # make everything valid
         flat_validx = np.arange(len(fx2_to_fx1) * K, dtype=index_dtype)
     else:
-        #fx2_to_flags = np.ones((len(fx2_to_fx1), K), dtype=np.bool)
+        #fx2_to_flags = np.ones((len(fx2_to_fx1), K), dtype=bool)
         flat_validx = np.flatnonzero(fx2_to_flags)
 
     match_fx2  = np.floor_divide(flat_validx, K, dtype=index_dtype)
@@ -1912,7 +1910,7 @@ def flag_sym_slow(fx1_to_fx2, fx2_to_fx1, K):
         fx2_m = fx1_to_fx2[fx1, :K]
         # Find img2 features that have fx1 in their top K
         reverse_m = fx2_to_fx1[fx2_m, :K]
-        is_recip = (reverse_m == fx1).sum(axis=1).astype(np.bool)
+        is_recip = (reverse_m == fx1).sum(axis=1).astype(bool)
         fx1_to_flags.append(is_recip)
     fx1_to_flags = np.array(fx1_to_flags)
     return fx1_to_flags
